<div class="sponsor">
    <a href="http://www.missbarbell.co.uk" target="sponsor"><img src="/images/promo/mbp-logo.jpg" border="0" alt="Miss Barbell Productions" align="right" /></a>
    <p align="justify">Miss Barbell Productions are a UK Midlands based company, providing web site design & development. Their flagship product, <a href="http://labyrinth.missbarbell.co.uk" target="sponsor">Labyrinth</a>, is an Open Source website management system, providing Content Management System (CMS) capabilities within a framework that describes your website.</p>
    <p align="justify">For further information regarding <a href="http://www.missbarbell.co.uk" target="sponsor">Miss Barbell Productions</a>, please visit their website.</p>
</div>
