[% 
    title = 'Login' ;

    crumb1_name = 'Login' ;
%]

[% IF errmess %]
<p>I'm sorry but that login was not recognised. Please try again, ensuring you enter the correct email address and password. Thank you.</p>
[% END %]

<form method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name='act'    value='user-logged' />
<input type="hidden" name='userid' value='[% data.userid %]' />

<table width="80%" summary="Login Form">
<tr><th><label for="cause">Email</label></th>
    <td><input type="text" id="cause" name="cause" /></td>
    <td rowspan="2">
      <p>Forgot your password? Not to worry, just enter your email and click the
      'forgot my password' button below. We will then send you a new password.</p>
    </td>
</tr>
<tr><th><label for="effect">Password</label></th>
    <td><input type="password" id="effect" name="effect" /></td>
</tr>
<tr><td></td>
    <td><input type="submit" name="submit" value='LOGIN' /></td>
    <td><input type="submit" id="forgot" name="forgot" value='FORGOT MY PASSWORD' /> or
        <a href="[% cgipath %]/pages.cgi?act=user-reg"><input type="button" id="signup" value="SIGN-UP" /></a></td>
</tr>
</table>

</form>
