<div class="footer">

		<p>
	  The CPAN Testers server is supported and funded by <a href="http://birmingham.pm.org" title="Birmingham Perl Mongers">Birmingham Perl Mongers</a>.<br />
		[% iname %] v[% version %] is powered by <a href="http://labyrinth.missbarbell.co.uk" title="Labyrinth Website Management Framework">Labyrinth</a> v[% labversion %]<br />
		[% copyright %] Comments and design patches to barbie@cpan.org.
    </p>
    
		<p>
    The CPAN Testers Family: <br />
      <a href="http://blog.cpantesters.org"     title="CPAN Testers Blog"       >Blog</a>         &#8226;
      <a href="http://www.cpantesters.org"      title="CPAN Testers Reports"    >Reports</a>      &#8226;
      <a href="http://wiki.cpantesters.org"     title="CPAN Testers Wiki"       >Wiki</a>         &#8226;
      <a href="http://stats.cpantesters.org"    title="CPAN Testers Statistics" >Statistics</a>   &#8226;
      <a href="http://pass.cpantesters.org"     title="CPAN Testers PASS Matrix">PASS Matrix</a>  &#8226;
      <a href="http://prefs.cpantesters.org"    title="CPAN Testers Preferences">Preferences</a>  &#8226;
      <a href="http://metabase.cpantesters.org" title="CPAN Testers Metabase"   >Metabase</a>     &#8226;
      <a href="http://devel.cpantesters.org"    title="CPAN Testers Development">Development</a>  &#8226;
      <a href="http://deps.cpantesters.org"     title="CPAN Dependencies"       >Dependencies</a> &#8226;
      <a href="http://matrix.cpantesters.org"   title="CPAN Testers Matrix"     >Matrix</a>       &#8226;
      <a href="http://analysis.cpantesters.org" title="CPAN Testers Analysis"   >Analysis</a>     &#8226;
      <a href="http://admin.cpantesters.org"    title="CPAN Testers Admin"      >Admin</a>
	  </p>
    <p>
    CPAN Testers, supporting the Perl programming language since 1999.
    </p>

</div>
