[% 
    title = "Mail Error" ;

    crumb1_name = 'Mail Error' ;
%]

<p>I'm sorry, there appears to have been a problem sending mail at the moment,
as it would seem our server has unfortunately not been able to process the mail 
about to be sent. We apologise for this inconvience, and will try to rectify 
the problem as soon as possible.</p>

<p>Thank You.</p>

