[% 
    title = "Error" ;

    crumb1_name = 'Error' ;
%]

<p>I'm sorry an error appears to have occurred that I cannot resolve. Please try
the request again shortly, and if the symptom still persists, please contact
the site <a href="mailto:[% administrator %]" title="Contact the administrator">administrator</a>. 
Thank you.</p>
