[% 
    title = "Banned User" ;
    crumb1_name = 'Banned User' ;
%]

<p>Your user login has been banned from using this site due to inappropriate behaviour.
If you feel this judgement has been made in error, please contact the site
<a href="mailto:[% administrator %]" title="Contact the administrator">administrator</a>. 
Please note that user logins will not be reinstated without confirmation of your email 
address.
