[% 
    htmltitle = 'Events &amp; Meetings' ;
    title = 'Events & Meetings' ;

    crumb2_name = 'Events' ;
    crumb2_href = '/event/main' ;
    crumb1_name = 'List' ;
%]

[% IF user.access >= 4 %]
<p>
      <a href="[% cgipath %]/pages.cgi?act=event-prev">previous events</a>
    | <a href="[% cgipath %]/pages.cgi?act=event-admin">admin events</a>
    | <a href="[% cgipath %]/pages.cgi?act=event-add">create an event</a>
</p>
[% END %]

<p>Below are all the events, that we are aware of, that feature talks, tutorials or
similar regarding CPAN Testers, Perl QA or Perl Testing. If you know of any event not 
listed here, please send <a href="mailto:barbie@cpan.org">Barbie</a> an email, with a 
link to the event, or with any further details if you are an organiser of an event,
and we will add it to our listings, if appropriate.</p>

<!--
<p>You can now download the latest ICalendar for my appearances.
<a class="more" href="[% cgipath %]/pages.cgi?act=event-ical">Click here</a> for a copy.</p>
-->

<form method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name='act' value='event-main' />
<input type="hidden" name='eventid' value='' />
<p>Search: [% events.ddtypes %] <input type="submit" value='GO' /></p>
</form>

[% IF events.longlist %]
[% FOREACH item = events.longlist %]
<hr class="clear-contentunit" />
<h2>[% item.eventdate %] - [% item.title %]</h2>
    [% IF event.venue %]
<p> [% IF item.venuelink %]<a href="[% item.venuelink %]" title="[% item.venue %]">[% item.venue %],</a>
    [% ELSE %][% item.venue %],
    [% END %]
    [% IF item.addresslink %]<br /><a href="[% item.addresslink %]" title="Map Link">[% item.address %]</a>
    [% ELSE %][% item.address %]
    [% END %]
</p>
    [% END %]

    [% item.snippet %]
    <p>... <a href="/event/[% item.eventid %]" title="[% item.title %]">read more details</a>.</p>

[% END %]

[% ELSE %]
<p align="center">No events currently listed</p>
[% END %]
