<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en-gb" lang="en-gb">

<head>
	<title>[% iname %]</title>

  <meta http-equiv="Content-Type"         content="text/html; charset=iso-8859-1" />
  <meta http-equiv="Content-Language"     content="en-gb" />
  <meta http-equiv="Content-Style-Type"   content="text/css" />
  <meta http-equiv="Content-Script-Type"  content="text/javascript" />

  <meta name="Generator"          content="Labyrinth" />
  <meta name="keywords"           content="perl,cpan,testing,testers" />
  <meta name="description"        content="The latest news and views about CPAN Testers" />
  <meta name="copyright"          content="Copyright (C) 2007-2011 CPAN Testers" />

  <link rel="stylesheet" type="text/css" media="screen" href="[% webpath %]/css/master.css" />

<!--

  Site Layout &amp; Design by Miss Barbell Productions for Kev Richards Promotions
  Powered by LAMP (Linux, Apache, MySQL &amp; Perl) technologies.
  Produced by LABYRINTH, a state of the art Website Management System available from Miss Barbell Productions
  For more information contact Barbie <barbie@missbarbell.co.uk>

-->

<body>

    <!-- Begin: Page Container -->
    <div id="popupcontainer">

        <!-- Begin: Page Body -->
        <div id="popupbody">

            <!-- Begin: Centre Column -->
            [% INCLUDE "$content" %]
            <!-- End: Centre Column -->

        </div>
        <!-- End: Page Body -->

    </div>
    <!-- End: Page Container -->

</body>
</html>
